==> aliyun-python-sdk-sls-1.0.8.tar.gz: aliyun-python-sdk-sls-1.0.8/aliyunsdksls/request/v20191023/SetAlertActionPolicyRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksls.endpoint import endpoint_data

class SetAlertActionPolicyRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sls', '2019-10-23', 'SetAlertActionPolicy')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_App(self):
		return self.get_body_params().get('App')

	def set_App(self,App):
		self.add_body_params('App', App)

	def get_PolicyId(self):
		return self.get_body_params().get('PolicyId')

	def set_PolicyId(self,PolicyId):
		self.add_body_params('PolicyId', PolicyId)

	def get_Policy(self):
		return self.get_body_params().get('Policy')

	def set_Policy(self,Policy):
		self.add_body_params('Policy', Policy)

==> aliyun-python-sdk-sls-1.1.1.tar.gz: aliyun-python-sdk-sls-1.1.1/aliyunsdksls/request/v20191023/SetAlertActionPolicyRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksls.endpoint import endpoint_data

class SetAlertActionPolicyRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sls', '2019-10-23', 'SetAlertActionPolicy','sls')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_App(self):
		return self.get_body_params().get('App')

	def set_App(self,App):
		self.add_body_params('App', App)

	def get_PolicyId(self):
		return self.get_body_params().get('PolicyId')

	def set_PolicyId(self,PolicyId):
		self.add_body_params('PolicyId', PolicyId)

	def get_PolicyName(self):
		return self.get_body_params().get('PolicyName')

	def set_PolicyName(self,PolicyName):
		self.add_body_params('PolicyName', PolicyName)

	def get_Policy(self):
		return self.get_body_params().get('Policy')

	def set_Policy(self,Policy):
		self.add_body_params('Policy', Policy)
